@@ -2,9 +2,9 @@
 package Require::HookChain;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-04-22'; # DATE
+our $DATE = '2023-05-03'; # DATE
 our $DIST = 'Require-HookChain'; # DIST
-our $VERSION = '0.013'; # VERSION
+our $VERSION = '0.014'; # VERSION
 
 #IFUNBUILT
 # use strict;
@@ -136,7 +136,7 @@ sub src {
 }
 
 1;
-# ABSTRACT: Chainable require hook
+# ABSTRACT: Chainable require hooks
 
 __END__
 
@@ -146,11 +146,11 @@ __END__
 
 =head1 NAME
 
-Require::HookChain - Chainable require hook
+Require::HookChain - Chainable require hooks
 
 =head1 VERSION
 
-This document describes version 0.013 of Require::HookChain (from Perl distribution Require-HookChain), released on 2023-04-22.
+This document describes version 0.014 of Require::HookChain (from Perl distribution Require-HookChain), released on 2023-05-03.
 
 =head1 SYNOPSIS
 
@@ -184,10 +184,11 @@ In a code to use this hook:
  use Require::HookChain 'munge::prepend' => 'use strict';
  use Foo::Bar; # Foo/Bar.pm will be loaded with added 'use strict;' at the start
 
-Install another hook, but put it at the end of C<@INC> instead of at the
+Install other hooks, but put it at the end of C<@INC> instead of at the
 beginning:
 
  use Require::HookChain -end => 1, append => 'some code';
+ use Require::HookChain 'log::stderr'; # log each loading of module to stderr
 
 =head1 DESCRIPTION
 
